@@ -1,5 +1,7 @@
 package Path::Class::Dir;
 
+$VERSION = '0.17';
+
 use strict;
 use Path::Class::File;
 use Path::Class::Entity;
@@ -11,6 +13,13 @@ use File::Path ();
 
 sub new {
   my $self = shift->SUPER::new();
+
+  # If the only arg is undef, it's probably a mistake.  Without this
+  # special case here, we'd return the root directory, which is a
+  # lousy thing to do to someone when they made a mistake.  Return
+  # undef instead.
+  return if @_==1 && !defined($_[0]);
+
   my $s = $self->_spec;
   
   my $first = (@_ == 0     ? $s->curdir :
@@ -36,8 +45,8 @@ sub as_foreign {
   
   # Clone internal structure
   $foreign->{volume} = $self->{volume};
-  my ($s, $fs) = ($self->_spec, $foreign->_spec);
-  $foreign->{dirs} = [ map {$_ eq $s->updir ? $fs->updir : $_} @{$self->{dirs}}];
+  my ($u, $fu) = ($self->_spec->updir, $foreign->_spec->updir);
+  $foreign->{dirs} = [ map {$_ eq $u ? $fu : $_} @{$self->{dirs}}];
   return $foreign;
 }
 
@@ -195,7 +204,7 @@ sub subsumes {
   my ($self, $other) = @_;
   die "No second entity given to subsumes()" unless $other;
   
-  $other = ref($self)->new($other) unless UNIVERSAL::isa($other, __PACKAGE__);
+  $other = $self->new($other) unless UNIVERSAL::isa($other, __PACKAGE__);
   $other = $other->dir unless $other->is_dir;
   
   if ($self->is_absolute) {
@@ -210,16 +219,25 @@ sub subsumes {
   if ($self->volume) {
     return 0 unless $other->volume eq $self->volume;
   }
+
+  # The root dir subsumes everything (but ignore the volume because
+  # we've already checked that)
+  return 1 if "@{$self->{dirs}}" eq "@{$self->new('')->{dirs}}";
   
   my $i = 0;
   while ($i <= $#{ $self->{dirs} }) {
-    return 0 unless exists $other->{dirs}[$i];
+    return 0 if $i > $#{ $other->{dirs} };
     return 0 if $self->{dirs}[$i] ne $other->{dirs}[$i];
     $i++;
   }
   return 1;
 }
 
+sub contains {
+  my ($self, $other) = @_;
+  return !!(-d $self and (-e $other or -l $other) and $self->subsumes($other));
+}
+
 1;
 __END__
 
@@ -238,11 +256,13 @@ Path::Class::Dir - Objects representing directories
   print "dir: $dir\n";
   
   if ($dir->is_absolute) { ... }
+  if ($dir->is_relative) { ... }
   
   my $v = $dir->volume; # Could be 'C:' on Windows, empty string
                         # on Unix, 'Macintosh HD:' on Mac OS
   
   $dir->cleanup; # Perform logical cleanup of pathname
+  $dir->resolve; # Perform physical cleanup of pathname
   
   my $file = $dir->file('file.txt'); # A file in this directory
   my $subdir = $dir->subdir('george'); # A subdirectory
@@ -252,7 +272,7 @@ Path::Class::Dir - Objects representing directories
   my $rel = $abs->relative; # Transform to relative path
   my $rel = $abs->relative('/foo'); # Relative to /foo
   
-  print $dir->as_foreign('MacOS'); # :foo:bar:
+  print $dir->as_foreign('Mac');   # :foo:bar:
   print $dir->as_foreign('Win32'); #  foo\bar
 
   # Iterate with IO::Dir methods:
@@ -321,6 +341,11 @@ C<dir()>) refers to the current directory (C<< File::Spec->curdir >>).
 To get the current directory as an absolute path, do C<<
 dir()->absolute >>.
 
+Finally, as another special case C<dir(undef)> will return undef,
+since that's usually an accident on the part of the caller, and
+returning the root directory would be a nasty surprise just asking for
+trouble a few lines later.
+
 =item $dir->stringify
 
 This method is called internally when a C<Path::Class::Dir> object is
@@ -346,6 +371,11 @@ return false, and C<Path::Class::Dir> objects always return true.
 Returns true or false depending on whether the directory refers to an
 absolute path specifier (like C</usr/local> or C<\Windows>).
 
+=item $dir->is_relative
+
+Returns true or false depending on whether the directory refers to a
+relative path specifier (like C<lib/foo> or C<./dir>).
+
 =item $dir->cleanup
 
 Performs a logical cleanup of the file path.  For instance:
@@ -353,6 +383,16 @@ Performs a logical cleanup of the file path.  For instance:
   my $dir = dir('/foo//baz/./foo')->cleanup;
   # $dir now represents '/foo/baz/foo';
 
+=item $dir->resolve
+
+Performs a physical cleanup of the file path.  For instance:
+
+  my $dir = dir('/foo//baz/../foo')->resolve;
+  # $dir now represents '/foo/foo', assuming no symlinks
+
+This actually consults the filesystem to verify the validity of the
+path.
+
 =item $file = $dir->file( <dir1>, <dir2>, ..., <file> )
 
 Returns a C<Path::Class::File> object representing an entry in C<$dir>
@@ -453,6 +493,12 @@ assume it's a directory.
   dir('/foo/bar')->subsumes(dir('foo/bar'))      # False
 
 
+=item $boolean = $dir->contains($other)
+
+Returns true if this directory actually contains C<$other> on the
+filesystem.  C<$other> doesn't have to be a direct child of C<$dir>,
+it just has to be subsumed.
+
 =item $foreign = $dir->as_foreign($type)
 
 Returns a C<Path::Class::Dir> object representing C<$dir> as it would
