@@ -1,11 +1,16 @@
 package Path::Class::Entity;
 
+$VERSION = '0.17';
+
 use strict;
 use File::Spec;
+use File::stat ();
+use Cwd;
 
 use overload
   (
    q[""] => 'stringify',
+   'bool' => 'boolify',
    fallback => 1,
   );
 
@@ -35,13 +40,17 @@ sub new_foreign {
 }
 
 sub _spec { $_[0]->{file_spec_class} || 'File::Spec' }
+
+sub boolify { 1 }
   
 sub is_absolute { 
-    # 5.6.0 has a bug with regexes and stringification that's ticked by
-    # file_name_is_absolute().  Help it along.
-    $_[0]->_spec->file_name_is_absolute($_[0]->stringify) 
+  # 5.6.0 has a bug with regexes and stringification that's ticked by
+  # file_name_is_absolute().  Help it along with an explicit stringify().
+  $_[0]->_spec->file_name_is_absolute($_[0]->stringify) 
 }
 
+sub is_relative { ! $_[0]->is_absolute }
+
 sub cleanup {
   my $self = shift;
   my $cleaned = $self->new( $self->_spec->canonpath($self) );
@@ -49,6 +58,17 @@ sub cleanup {
   return $self;
 }
 
+sub resolve {
+  my $self = shift;
+  my $cleaned = $self->new( Cwd::realpath($self->stringify) );
+
+  # realpath() always returns absolute path, kind of annoying
+  $cleaned = $cleaned->relative if $self->is_relative;
+
+  %$self = %$cleaned;
+  return $self;
+}
+
 sub absolute {
   my $self = shift;
   return $self if $self->is_absolute;
@@ -60,4 +80,7 @@ sub relative {
   return $self->new($self->_spec->abs2rel($self->stringify, @_));
 }
 
+sub stat  { File::stat::stat("$_[0]") }
+sub lstat { File::stat::lstat("$_[0]") }
+
 1;
